///////////////////////////////////////////////////////////
//  STANAG2525CCategorizationData.cs
//  Implementation of the Class STANAG2525CCategorizationData
//  Generated by Enterprise Architect
//  Created on:      18-May-2018 15:46:58
//  Original author: simon.mettrick
///////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;



using Org.OMG.TACSIT.DataPayload.CategorizationData;
namespace Org.OMG.TACSIT.DataPayload.CategorizationData {
	/// <summary>
	/// The data needed for displaying the 2525C symbol set (TBD).
	/// 
	///        For a full definition of the specifications of using MILSTD-2525
	/// Symbology refer to the published version from the US-DOD.
	/// 
	///        Excerpt from Appendix A of the 2525C Symbology Standard:
	/// 
	///        A.5.1 Technical specifications. Composition, construction, display, and
	/// transmission of tactical symbols are explained in the detailed requirements
	/// section of the standard.
	///        A.5.2 Symbol identification coding scheme. A SIDC is a 15-character
	/// alphanumeric identifier that provides the information necessary to display or
	/// transmit a tactical symbol between MIL-STD-2525 compliant systems.
	/// 
	///        Apendix A of 2525C Specification outlines the order of concatenation of
	/// attribute data.  Copied here for convenience
	/// 
	///        Attribute - # of Chars
	///        Coding Scheme - 1 (S for Warfighting)
	///        Standard ID - 1
	///        Battle Dimension - 1
	///        Status/OPCON -1
	///        Function ID  - 6
	///        Symbol Modifier - 2
	///        Country Code - 2
	///        Order of Battle - 1
	/// </summary>
	public class STANAG2525CCategorizationData : MilitaryCategorizationData {

		private char codingScheme;
		private char standardID_AmpDescriptor;
		private char battleDimension;
		private char status_OPCON;
		private char functionID;
		private char symbolModifier;
		private char countryCode;
		private char orderOfBattle;

		/// <summary>
		/// Default Constructor
		/// </summary>
		public STANAG2525CCategorizationData(){

		}

		/// <summary>
		/// Full Constructor with parameters for each property
		/// </summary>
		public STANAG2525CCategorizationData(char the_codingScheme, char the_standardID_AmpDescriptor, char the_battleDimension, char the_status_OPCON, char the_functionID, char the_symbolModifier, char the_countryCode, char the_orderOfBattle){
			codingScheme = the_codingScheme;
			standardID_AmpDescriptor = the_standardID_AmpDescriptor;
			battleDimension = the_battleDimension;
			status_OPCON = the_status_OPCON;
			functionID = the_functionID;
			symbolModifier = the_symbolModifier;
			countryCode = the_countryCode;
			orderOfBattle = the_orderOfBattle;
		}

		/// <summary>
		/// Constructor with parameters for each mandatory property
		/// </summary>
		public STANAG2525CCategorizationData(char the_codingScheme, char the_standardID_AmpDescriptor, char the_battleDimension, char the_status_OPCON, char the_orderOfBattle){
			codingScheme = the_codingScheme;
			standardID_AmpDescriptor = the_standardID_AmpDescriptor;
			battleDimension = the_battleDimension;
			status_OPCON = the_status_OPCON;
			orderOfBattle = the_orderOfBattle;
		}

		~STANAG2525CCategorizationData(){

		}

		/// <summary>
		/// Version: See detailed specification of this field in the Specification (MIL-STD-
		/// 2525D Appendix A.5).
		/// </summary>
		public char CodingScheme{
			get{
				return codingScheme;
			}
			set{
				codingScheme = value;
			}
		}

		/// <summary>
		/// Standard Identity: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char StandardID_AmpDescriptor{
			get{
				return standardID_AmpDescriptor;
			}
			set{
				standardID_AmpDescriptor = value;
			}
		}

		/// <summary>
		/// Symbol Set: See detailed specification of this field in the Specification (MIL-
		/// STD-2525D Appendix A.5).
		/// </summary>
		public char BattleDimension{
			get{
				return battleDimension;
			}
			set{
				battleDimension = value;
			}
		}

		/// <summary>
		/// Status: See detailed specification of this field in the Specification (MIL-STD-
		/// 2525D Appendix A.5).
		/// </summary>
		public char Status_OPCON{
			get{
				return status_OPCON;
			}
			set{
				status_OPCON = value;
			}
		}

		/// <summary>
		/// HQ/Task Force/Dummy: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char FunctionID{
			get{
				return functionID;
			}
			set{
				functionID = value;
			}
		}

		/// <summary>
		/// Amplifier/Descriptor: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char SymbolModifier{
			get{
				return symbolModifier;
			}
			set{
				symbolModifier = value;
			}
		}

		/// <summary>
		/// Entity: See detailed specification of this field in the Specification (MIL-STD-
		/// 2525D Appendix A.5).
		/// </summary>
		public char CountryCode{
			get{
				return countryCode;
			}
			set{
				countryCode = value;
			}
		}

		public char OrderOfBattle{
			get{
				return orderOfBattle;
			}
			set{
				orderOfBattle = value;
			}
		}

	}//end STANAG2525CCategorizationData

}//end namespace CategorizationData