///////////////////////////////////////////////////////////
//  STANAG2525DCategorizationData.cs
//  Implementation of the Class STANAG2525DCategorizationData
//  Generated by Enterprise Architect
//  Created on:      18-May-2018 15:46:58
//  Original author: simon.mettrick
///////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;



using Org.OMG.TACSIT.DataPayload.CategorizationData;
namespace Org.OMG.TACSIT.DataPayload.CategorizationData {
	/// <summary>
	/// The data needed for displaying the 2525D symbol set (TBD).
	/// 
	///        For a full definition of the specifications of using MILSTD-2525
	/// Symbology refer to the latest published version from the US-DOD.
	/// 
	///        Excerpt from Appendix A of the 2525D Symbology Standard:
	/// 
	///        A.5.1 Symbol identification codes. A symbol identification code is a
	/// numeric code that uniquely identifies the elements needed to build a
	/// MILSTD2525D compliant symbol. The numeric codes provide the same type of
	/// descriptions used in message formats but further focus
	///        the data to a specific domain for ease in creating the symbols with less
	/// band width.
	///        A.5.2 Elements of the symbol identification codes. The symbol
	/// identification code is composed of eleven elements of information which are
	/// presented in two sets of ten digits. An additional set of ten digits composed
	/// of three elements must be used when a symbology
	///        originator version extension flag is used. This extension is conditional.
	/// 
	/// 
	///        Apendix A of 2525D Specification outlines the order of concatenation of
	/// attribute data.  Copied here for convenience
	/// 
	///        Attribute - # of Chars
	///        Set A:
	///        Version - 2
	///        Standard ID - 2
	///        Symbol Set - 2
	///        Status -1
	///        HQ Task Force Dummy - 1
	///        Amp / Descr - 2
	///        ------------------
	///        Set B:
	///        Entity - 2
	///        Entity Type - 2
	///        Entity Subtype - 2
	///        Sector 1 Mod - 2
	///        Sector 2 Mod - 2
	///        ---------------------
	///        Conditional Set C
	///        Symbology Orig ID - 3
	///        Symbology Orig Symbol Set - 1
	///        Specified by Symbol Originator - 2,2,2
	/// </summary>
	public class STANAG2525DCategorizationData : MilitaryCategorizationData {

		private char version;
		private char standardIdentity;
		private char symbolSet;
		private char status;
		private char hQ_TF_Dummy;
		private char amp_Descriptor;
		private char entity;
		private char entityType;
		private char entitySubType;
		private char sector1Mod;
		private char sector2Mod;
		private char cond_symbolOrigID;
		private char cond_symbolOrigSymbolSet;
		private char cond_specFromSymbolOrig;

		/// <summary>
		/// Default Constructor
		/// </summary>
		public STANAG2525DCategorizationData(){

		}

		/// <summary>
		/// Full Constructor with parameters for each property
		/// </summary>
		public STANAG2525DCategorizationData(char the_version, char the_standardIdentity, char the_symbolSet, char the_status, char the_hQ_TF_Dummy, char the_amp_Descriptor, char the_entity, char the_entityType, char the_entitySubType, char the_sector1Mod, char the_sector2Mod, char the_cond_symbolOrigID, char the_cond_symbolOrigSymbolSet, char the_cond_specFromSymbolOrig){
			version = the_version;
			standardIdentity = the_standardIdentity;
			symbolSet = the_symbolSet;
			status = the_status;
			hQ_TF_Dummy = the_hQ_TF_Dummy;
			amp_Descriptor = the_amp_Descriptor;
			entity = the_entity;
			entityType = the_entityType;
			entitySubType = the_entitySubType;
			sector1Mod = the_sector1Mod;
			sector2Mod = the_sector2Mod;
			cond_symbolOrigID = the_cond_symbolOrigID;
			cond_symbolOrigSymbolSet = the_cond_symbolOrigSymbolSet;
			cond_specFromSymbolOrig = the_cond_specFromSymbolOrig;
		}

		/// <summary>
		/// Constructor with parameters for each mandatory property
		/// </summary>
		public STANAG2525DCategorizationData(char the_status, char the_hQ_TF_Dummy){
			status = the_status;
			hQ_TF_Dummy = the_hQ_TF_Dummy;
		}

		~STANAG2525DCategorizationData(){

		}

		/// <summary>
		/// Version: See detailed specification of this field in the Specification (MIL-STD-
		/// 2525D Appendix A.5).
		/// </summary>
		public char Version{
			get{
				return version;
			}
			set{
				version = value;
			}
		}

		/// <summary>
		/// Standard Identity: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char StandardIdentity{
			get{
				return standardIdentity;
			}
			set{
				standardIdentity = value;
			}
		}

		/// <summary>
		/// Symbol Set: See detailed specification of this field in the Specification (MIL-
		/// STD-2525D Appendix A.5).
		/// </summary>
		public char SymbolSet{
			get{
				return symbolSet;
			}
			set{
				symbolSet = value;
			}
		}

		/// <summary>
		/// Status: See detailed specification of this field in the Specification (MIL-STD-
		/// 2525D Appendix A.5).
		/// </summary>
		public char Status{
			get{
				return status;
			}
			set{
				status = value;
			}
		}

		/// <summary>
		/// HQ/Task Force/Dummy: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char HQ_TF_Dummy{
			get{
				return hQ_TF_Dummy;
			}
			set{
				hQ_TF_Dummy = value;
			}
		}

		/// <summary>
		/// Amplifier/Descriptor: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char Amp_Descriptor{
			get{
				return amp_Descriptor;
			}
			set{
				amp_Descriptor = value;
			}
		}

		/// <summary>
		/// Entity: See detailed specification of this field in the Specification (MIL-STD-
		/// 2525D Appendix A.5).
		/// </summary>
		public char Entity{
			get{
				return entity;
			}
			set{
				entity = value;
			}
		}

		/// <summary>
		/// Entity Type: See detailed specification of this field in the Specification (MIL-
		/// STD-2525D Appendix A.5).
		/// </summary>
		public char EntityType{
			get{
				return entityType;
			}
			set{
				entityType = value;
			}
		}

		/// <summary>
		/// Entity Subtype: See detailed specification of this field in the Specification
		/// (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char EntitySubType{
			get{
				return entitySubType;
			}
			set{
				entitySubType = value;
			}
		}

		/// <summary>
		/// Sector 1 modifier: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char Sector1Mod{
			get{
				return sector1Mod;
			}
			set{
				sector1Mod = value;
			}
		}

		/// <summary>
		/// Sector 2 modifier: See detailed specification of this field in the
		/// Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char Sector2Mod{
			get{
				return sector2Mod;
			}
			set{
				sector2Mod = value;
			}
		}

		/// <summary>
		/// Conditional Set C Attribute - Symbology Originator ID: See detailed
		/// specification of this field in the Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char Cond_symbolOrigID{
			get{
				return cond_symbolOrigID;
			}
			set{
				cond_symbolOrigID = value;
			}
		}

		/// <summary>
		/// Conditional Set C Attribute - Symbology Originator Symbol Set: See detailed
		/// specification of this field in the Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char Cond_symbolOrigSymbolSet{
			get{
				return cond_symbolOrigSymbolSet;
			}
			set{
				cond_symbolOrigSymbolSet = value;
			}
		}

		/// <summary>
		/// Conditional Set C Attribute - Specified From Symbology Originator: See detailed
		/// specification of this field in the Specification (MIL-STD-2525D Appendix A.5).
		/// </summary>
		public char Cond_specFromSymbolOrig{
			get{
				return cond_specFromSymbolOrig;
			}
			set{
				cond_specFromSymbolOrig = value;
			}
		}

	}//end STANAG2525DCategorizationData

}//end namespace CategorizationData