///////////////////////////////////////////////////////////
//  EntityPayload.cs
//  Implementation of the Class EntityPayload
//  Generated by Enterprise Architect
//  Created on:      18-May-2018 16:30:08
//  Original author: simon.mettrick
///////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;



using Org.OMG.TACSIT.DataPayload.Util;
using Org.OMG.TACSIT.DataPayload.EntityPayload;
namespace Org.OMG.TACSIT.DataPayload.EntityPayload {
	/// <summary>
	/// The definition of an entity as it appears in the exchanges with TACSIT.
	///        The 'reportType' attributes gives the lifecycle status of this payload
	/// showing that it is a creation, a modification and so forth.
	/// 
	///        Note: the 'id' attribute is used by the TACSIT system to identify the
	/// EntityPayload while the 'identifier' attribute of the EntityMetatData is used
	/// by the system which requested the creation of this EntityPayload to identify it
	/// internally. 'identifier' is so a way to let this using system to find back its
	/// data when getting back an entity from TACSIT.
	/// </summary>
	public abstract class EntityPayload {

		private Uri id;
		private String label;
		private String info;
		private Org.OMG.TACSIT.DataPayload.Util.URL href;
		private TimeSpan timeSpan;
		private DateTime timeStamp;
		private Org.OMG.TACSIT.DataPayload.EntityPayload.ReportType? reportType;
		private Org.OMG.TACSIT.DataPayload.EntityPayload.EntityMetaData metaData;

		/// <summary>
		/// Default Constructor
		/// </summary>
		public EntityPayload(){

		}

		/// <summary>
		/// Full Constructor with parameters for each property
		/// </summary>
		public EntityPayload(Uri the_id, String the_label, String the_info, Org.OMG.TACSIT.DataPayload.Util.URL the_href, TimeSpan the_timeSpan, DateTime the_timeStamp, Org.OMG.TACSIT.DataPayload.EntityPayload.ReportType? the_reportType, Org.OMG.TACSIT.DataPayload.EntityPayload.EntityMetaData the_metaData){
			id = the_id;
			label = the_label;
			info = the_info;
			href = the_href;
			timeSpan = the_timeSpan;
			timeStamp = the_timeStamp;
			reportType = the_reportType;
			metaData = the_metaData;
		}

		~EntityPayload(){

		}

		/// <summary>
		/// A Uniform Resource Identifier (URI) that uniquely identifies the object.
		/// </summary>
		public Uri Id{
			get{
				return id;
			}
			set{
				id = value;
			}
		}

		/// <summary>
		/// Short description.
		/// </summary>
		public string Label{
			get{
				return label;
			}
			set{
				label = value;
			}
		}

		/// <summary>
		/// Additional human-readable text.
		/// </summary>
		public string Info{
			get{
				return info;
			}
			set{
				info = value;
			}
		}

		/// <summary>
		/// A URL to human readable content providing more information about the object.
		/// </summary>
		public Org.OMG.TACSIT.DataPayload.Util.URL Href{
			get{
				return href;
			}
			set{
				href = value;
			}
		}

		/// <summary>
		/// A show/hide period.
		/// </summary>
		public TimeSpan TimeSpan{
			get{
				return timeSpan;
			}
			set{
				timeSpan = value;
			}
		}

		/// <summary>
		/// The date of validity of the information held by the entity.
		/// </summary>
		public DateTime TimeStamp{
			get{
				return timeStamp;
			}
			set{
				timeStamp = value;
			}
		}

		/// <summary>
		/// Lifecycle status of the EntityPayload.
		///        Default is UPDATE.
		/// </summary>
		public Org.OMG.TACSIT.DataPayload.EntityPayload.ReportType? ReportType{
			get{
				return reportType;
			}
			set{
				reportType = value;
			}
		}

		/// <summary>
		/// Metadata for the entity. These metadata, if present, replace the ones of the
		/// group.
		/// </summary>
		public Org.OMG.TACSIT.DataPayload.EntityPayload.EntityMetaData MetaData{
			get{
				return metaData;
			}
			set{
				metaData = value;
			}
		}

		/// <summary>
		/// Determine whether EntityPayload has a valid metaData property.
		/// </summary>
		public bool MetaDataExists(){

			return (metaData != null);
		}

	}//end EntityPayload

}//end namespace EntityPayload